@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Conf;
-$ExtUtils::Builder::Conf::VERSION = '0.017';
+$ExtUtils::Builder::Conf::VERSION = '0.018';
 use strict;
 use warnings;
 
@@ -26,8 +26,8 @@ sub add_methods {
 			return @{ $self->{$name} || [] };
 		});
 		$planner->add_delegate("push_$name", sub {
-			my $self = shift;
-			push @{ $self->{$name} }, @_;
+			my ($self, @args) = @_;
+			push @{ $self->{$name} }, @args;
 		});
 	}
 
@@ -80,8 +80,6 @@ sub add_methods {
 
 		my ($source_file, $c_file) = tempfile('try_compilerXXXX', DIR => $dir, SUFFIX => '.c');
 
-		print $source_file $args{source};
-
 		my $inner = $self->new_planner;
 		$inner->load_module('ExtUtils::Builder::AutoDetect::C', 0.015);
 
@@ -93,7 +91,7 @@ sub add_methods {
 			include_dirs => \@include_dirs,
 		);
 
-		my $basename = basename($c_file);
+		my $basename = basename($c_file, '.c');
 		my $o_file = $inner->obj_file($basename);
 		$inner->compile($c_file, $o_file, %compile_args);
 
@@ -118,7 +116,6 @@ sub add_methods {
 				target       => 'test',
 				dependencies => [ $exe_file ],
 				actions      => [
-					ExtUtils::Builder::Action::Command->new(command => [ 'echo', "running $exe_file" ]),
 					ExtUtils::Builder::Action::Command->new(command => [ catfile(curdir, $exe_file) ]),
 				],
 				phony        => 1,
@@ -177,21 +174,37 @@ sub add_methods {
 		return !!0;
 	});
 
-	$planner->add_delegate(try_find_libs_for => sub {
+	$planner->add_delegate(try_find_libraries_for => sub {
 		my ($self, %args) = @_;
 
 		ref(my $libs = $args{libs}) eq "ARRAY" or croak "Expected 'libs' as ARRAY ref";
 
 		foreach my $libraries (@$libs) {
 			$self->try_compile_run(%args, libraries => $libraries) or next;
-			$self->push_extra_linker_flags(@$libraries);
+			$self->push_libraries(@$libraries);
 			return !!1;
 		}
 
 		return !!0;
 	});
 
-	foreach my $name (qw/find_cflags_for find_libs_for find_include_dirs_for/) {
+	$planner->add_delegate(try_find_library_dirs_for => sub {
+		my ($self, %args) = @_;
+
+		ref(my $dirs = $args{dirs}) eq "ARRAY" or croak "Expected 'dirs' as ARRAY ref";
+
+		foreach my $d (@$dirs) {
+			ref $d eq "ARRAY" or croak "Expected 'dirs' element as ARRAY ref";
+
+			$self->try_compile_run(%args, library_dirs => $d) or next;
+			$self->push_library_dirs(@$d);
+			return !!1;
+		}
+
+		return !!0;
+	});
+
+	foreach my $name (qw/find_cflags_for find_libraries_for find_include_dirs_for find_library_dirs_for/) {
 		my $trymethod = "try_$name";
 
 		$planner->add_delegate($name, sub {
@@ -219,7 +232,7 @@ ExtUtils::Builder::Conf - Configure-time utilities for using C headers, librarie
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
@@ -269,7 +282,7 @@ Optional. If specified, pass extra flags to the linker.
 
 =item define => STRING
 
-Optional. If specified, then the named symbol will be defined if the program ran successfully. This will either on the C compiler commandline (by passing an option C<-DI<SYMBOL>>), or in the C<defines_to> file.
+Optional. If specified, then the named symbol will be defined if the program ran successfully. This will either on the C compiler commandline (by passing an option C<-DI<SYMBOL>>), in the C<defines> method, or via the C<write_defines> method.
 
 =back
 
@@ -313,7 +326,7 @@ Gives a list of sets of flags. Each set of flags should be strings in its own ar
 
 =item define => STRING
 
-Optional. If specified, then the named symbol will be defined if the program ran successfully.
+Optional. If specified, then the named symbol will be defined if the program ran successfully. This will either on the C compiler commandline (by passing an option C<-DI<SYMBOL>>), in the C<defines> method, or via the C<write_defines> method.
 
 =back
 
@@ -341,17 +354,17 @@ Gives a list of sets of dirs. Each set of dirs should be strings in its own arra
 
 =item define => STRING
 
-Optional. If specified, then the named symbol will be defined if the program ran successfully. This will either on the C compiler commandline (by passing an option C<-DI<SYMBOL>>), or in the C<defines_to> file.
+Optional. If specified, then the named symbol will be defined if the program ran successfully. This will either on the C compiler commandline (by passing an option C<-DI<SYMBOL>>), in the C<defines> method, or via the C<write_defines> method.
 
 =back
 
-=head2 try_find_libs_for
+=head2 try_find_libraries_for
 
- $success = try_find_libs_for(%args);
+ $success = try_find_libraries_for(%args);
 
 Try to compile, link and execute the given source, when linked against a given set of extra libraries.
 
-When a usable combination is found, the libraries required are stored in the object for use in further link operations, or returned by C<extra_linker_flags>. The method then returns true.
+When a usable combination is found, the libraries required are stored in the object for use in further link operations, or returned by C<libraries>. The method then returns true.
 
 If no usable combination is found, it returns false.
 
@@ -369,7 +382,35 @@ Gives a list of sets of libraries. Each set of libraries should be space-separat
 
 =item define => STRING
 
-Optional. If specified, then the named symbol will be defined if the program ran successfully. This will either on the C compiler commandline (by passing an option C<-DI<SYMBOL>>), or in the C<defines_to> file.
+Optional. If specified, then the named symbol will be defined if the program ran successfully. This will either on the C compiler commandline (by passing an option C<-DI<SYMBOL>>), in the C<defines> method, or via the C<write_defines> method.
+
+=back
+
+=head2 try_find_library_dirs_for
+
+ $success = try_find_library_dirs_for(%args);
+
+Try to compile, link and execute the given source, using extra library directories.
+
+When a usable combination is found, the directories required are stored in the object for use in further compile operations, or returned by C<library_dirs>. The method then returns true.
+
+If no a usable combination is found, it returns false.
+
+Takes the following arguments:
+
+=over 4
+
+=item source => STRING
+
+Source code to compile
+
+=item dirs => ARRAY of ARRAYs
+
+Gives a list of sets of dirs. Each set of dirs should be strings in its own array reference.
+
+=item define => STRING
+
+Optional. If specified, then the named symbol will be defined if the program ran successfully. This will either on the C compiler commandline (by passing an option C<-DI<SYMBOL>>), in the C<defines> method, or via the C<write_defines> method.
 
 =back
 
@@ -381,11 +422,11 @@ Optional. If specified, then the named symbol will be defined if the program ran
 
  find_include_dirs_for(%args);
 
-=head2 find_libs_for
+=head2 find_libraries_for
 
- find_libs_for(%args);
+ find_libraries_for(%args);
 
-Calls C<try_find_cflags_for>, C<try_find_include_dirs_for> or C<try_find_libs_for> respectively. If it fails, die with an C<OS unsupported> message.
+Calls C<try_find_cflags_for>, C<try_find_include_dirs_for> or C<try_find_libraries_for> respectively. If it fails, die with an C<OS unsupported> message.
 
 Each method takes one extra optional argument:
 
@@ -469,7 +510,7 @@ Adds a new defined symbol directly; either by appending to the compiler flags or
 
 Some operating systems provide the BSD sockets API in their primary F<libc>. Others keep it in a separate library which should be linked against. The following example demonstrates how this would be handled.
 
- find_libs_for(
+ find_libraries_for(
    diag => 'no socket()',
    libs => [ [], ['socket', 'nsl' ]],
    source => q[
